@@ -1,4 +1,5 @@
 package Device::Network::ConfigParser;
+# ABSTRACT: A harness for parsing network device configuration.
 
 
 use 5.006;
@@ -18,7 +19,6 @@ use Exporter qw{import};
 our @EXPORT_OK = qw{app};
 
 
-
 sub app {
     local @ARGV = @_;
     my %args;
@@ -114,28 +114,68 @@ __END__
 
 =head1 NAME
 
-Device::Network::ConfigParser
+Device::Network::ConfigParser - A harness for parsing network device configuration.
 
 =head1 VERSION
 
-version 0.003
+version 0.004
 
 =head1 SYNOPSIS
 
-=head1 NAME
+Device::Network::ConfigParser is a harness for parsing network device configuration. It exports a single subroutine - C<app()> - which takes command line arguments and runs the harness. This module is used by the C<ncp> command line utility. For information on how to use the command line utility, refer to the L<ncp>, or following installation type C<perldoc ncp> at the command line.
 
-Device::Network::ConfigParser - Harness for parsing network device confiugrations
+The harness supports specific parsing modules by:
 
-=head1 VERSION
+=over 4
 
-# VERSION
+=item * Dynamically loading a specific parsing module based on command line arguments.
 
-=head1 EXPORT
+=item * Slurping in the device configuration from STDIN or from a number of files.
+
+=item * Opening the required output filehandles.
+
+=back
+
+=head1 DEVELOPING MODULES
+
+Parsing modules exist within the C<Device::Network::ConfigParser::> namespace. For a I<vendor> and I<type> of device, the module is defined as C<Device::Network::ConfigParser::vendor::type>.
+
+The harness takes care of parsing the command line arguments, opening files (or STDIN/STDOUT) and slurping in their contents. It calls specified subroutines exported by the specified parsing module. Any module must export the following subroutines:
+
+=over 4
+
+=item * B<get_parser>
+
+This sub receives no arguments, and must return a reference to an object or another subroutine that parses the configuration. This is most likely going to be a Parse::RecDescent object, but you're not limited to this.
+
+=item * B<parse_config>
+
+This sub receives the reference returned by the C<get_parser> sub, and the full contents of a file specified on the command line. It should return a reference a data structure that represents the parsed configuration.
+
+=item * B<post_process>
+
+This sub receives the reference to the data structure returned by C<parse_config>. It allows for some post-processing of the data structure. If no processing is required, it can be defined as C<sub post_process { return @_; }>.
+
+=item * B<get_output_drivers>
+
+This sub receives no arguments, and must return a HASHREF of subroutines used to output the parsed configurationm keyed on the command line argument. For example the sub may return:
+
+    {
+        csv => \&csv_output_driver,
+    }  
+
+If the user specified C<--output csv> as a command line argument, the C<csv_output_driver> would be called. When called, each output driver receives a filehandle to write the output to, the name of the file, and the post-processed data structure.
+
+There is a default 'raw' driver always present, which uses Data::Dumper to serialise the structure. The module may return its own 'raw' driver which will override this default.
+
+=back
 
 =head1 SUBROUTINES
 
 =head2 app 
 
+The C<app> subroutine in general takes C<@ARGV> (although it could be any list) and runs the harness.
+
 =head1 AUTHOR
 
 Greg Foletta, C<< <greg at foletta.org> >>
